Imports System
Imports System.Collections
Imports TXTextControl
Imports Keyoti.RapidSpell



Public Class TXHelper
    Private ayt As RapidSpellAsYouType
    Private dia As RapidSpellDialog
    Private WithEvents txc As TXTextControl.TextControl
    Private dialogAdapter As TXTextControlAdapter
    Private adapters() As TXTextControlAdapter
    Private _isTextFrameActive = False

    Public ReadOnly Property IsTextFrameActive() As Boolean
        Get
            Return _isTextFrameActive
        End Get
    End Property



    ' Configures the spell checkers to work with the text control, pass a null
    ' spell checker object if not being used.
    Public Sub New(ByVal ayt As RapidSpellAsYouType, ByVal dia As RapidSpellDialog, ByVal txc As TXTextControl.TextControl)
        Me.ayt = ayt
        Me.dia = dia
        Me.txc = txc

        If Not (dia Is Nothing) Then
            dialogAdapter = New TXTextControlAdapter(txc)
            dialogAdapter.WorkWithCurrentlyActiveElementOnly = True
            Me.dia.ThirdPartyTextComponentToCheck = dialogAdapter
            AddHandler dia.SpellCheckStarted, AddressOf dia_SpellCheckStarted
            AddHandler dia.SpellCheckFinished, AddressOf dia_SpellCheckFinished
        End If

        If Not (ayt Is Nothing) Then
            AddHandler Me.txc.TextFrameCreated, AddressOf txc_TextFrameCreated
            adapters = CType(getBasisAdapters().ToArray(GetType(TXTextControlAdapter)), TXTextControlAdapter())
            Me.ayt.UpdateAllTextBoxes = False
            Me.ayt.TextComponents = adapters
        End If

    End Sub 'New


    Function getBasisAdapters() As ArrayList
        Dim adaps As New ArrayList
        Dim adap As TXTextControlAdapter

        'add main adapter
        adap = New TXTextControlAdapter(Me.txc)
        adaps.Add(adap)

        'add adapters for headers/footers
        Dim hf As HeaderFooter
        For Each hf In Me.txc.HeadersAndFooters
            adap = New TXTextControlAdapter(Me.txc)
            adap.HeaderFooter = hf
            adaps.Add(adap)
        Next hf
        Return adaps
    End Function 'getBasisAdapters


    Private Sub dia_SpellCheckStarted(ByVal sender As Object, ByVal e As Keyoti.RapidSpell.Event.SpellCheckEventArgs)
        dialogAdapter.IgnoreHeaderFooterDeactivationEvents = True
    End Sub 'dia_SpellCheckStarted


    Private Sub dia_SpellCheckFinished(ByVal sender As Object, ByVal e As Keyoti.RapidSpell.Event.SpellCheckEventArgs)
        dialogAdapter.IgnoreHeaderFooterDeactivationEvents = False
    End Sub 'dia_SpellCheckFinished


    'used for AYT only, this is only called when text frames come from the CLIPBOARD
    Private Sub txc_TextFrameCreated(ByVal sender As Object, ByVal e As TextFrameEventArgs)
        OnTextFrameCreated(e.TextFrame)
    End Sub 'txc_TextFrameCreated


    'used for AYT only
    ' Call when adding a TextFrame
    Public Sub OnTextFrameCreated(ByVal tf As TextFrame)
        Dim basis As New ArrayList
        Dim adap As TXTextControlAdapter

        'refresh old adapters, note we must create new adapters as old ones are retired below
        Dim a As TXTextControlAdapter
        For Each a In adapters

            adap = New TXTextControlAdapter(Me.txc)
            adap.SetWith(a)
            basis.Add(adap)
        Next a

        'text frame adapter
        adap = New TXTextControlAdapter(Me.txc)
        adap.TextFrame = tf
        basis.Add(adap)

        adapters = CType(basis.ToArray(GetType(TXTextControlAdapter)), TXTextControlAdapter())

        'retire the old ones
        ayt.TextComponents = Nothing
        'add the new ones
        ayt.TextComponents = adapters
    End Sub 'OnTextFrameCreated



    Private Sub txc_TextFrameActivated(ByVal sender As Object, ByVal e As TXTextControl.TextFrameEventArgs) Handles txc.TextFrameActivated
        Me._isTextFrameActive = True
    End Sub

    Private Sub txc_TextFrameDeactivated(ByVal sender As Object, ByVal e As TXTextControl.TextFrameEventArgs) Handles txc.TextFrameDeactivated
        Me._isTextFrameActive = False
    End Sub
End Class 'TXHelper

